<template>
    <div class="app-container">
        <div class="filter-container">
            <div style="display: block;">
                <div class="basic_search" style="padding-top: 10px">
                    <span>按企业名称：</span>
                    <el-input filterable clearable v-model="listQuery.filter.enterprisename" style="width:200px">
                    </el-input>
                </div>
                <div class="basic_search" style="padding-top: 10px">
                    <span>按单号：</span>
                    <el-input filterable clearable v-model="listQuery.filter.code" style="width:200px">
                    </el-input>
                </div>
                <div class="basic_search" style="padding-top: 10px">
                    <span>按状态：</span>
                    <el-select filterable clearable v-model="listQuery.filter.appealstatus" style="width:200px">
                        <el-option
                            v-for="item in appealStatusList"
                            :key="item.id"
                            :value="item.id"
                            :label="item.text"
                        ></el-option>
                    </el-select>
                </div>
                <div class="basic_search" style="margin-right: 10px">
                    <el-button style="margin-left: 10px;" type="primary" icon="el-icon-search" @click="search('查询','')">查询</el-button>
                </div>
            </div>
        </div>
        <div class="table_content">
            <el-table
                v-loading="listLoading"
                :key="tableKey"
                :data="productJudgeData"
                border
                fit
                highlight-current-row
                style="width: 100%;"
            >
                <el-table-column label="序号" type="index" align="center" width="60"/>
                <el-table-column label="企业名称" prop="enterprisename" align="center">
                </el-table-column>
                <el-table-column label="单号" prop="code" align="center">
                </el-table-column>
                <el-table-column label="审批通过时间" prop="approvetime" align="center">
                </el-table-column>
                <el-table-column label="申诉截止日期" prop="deadline" align="center">
                    <template slot-scope="scope">
                               <span :class="scope.row.iswarn?'warn-tip':''">{{scope.row.deadline.concat(" 截止")}}</span>
                    </template>
                </el-table-column>
                <el-table-column label="处罚类型" prop="punishmentmeasure" align="center">
                    <template slot-scope="scope">
                        <div v-for="item in punishmentMeasureList">
                            <div v-if="scope.row.punishmentmeasure === item.value">
                                <span>{{item.text}}</span>
                            </div>
                        </div>
                    </template>
                </el-table-column>
                <el-table-column label="处罚原因" prop="punishmentreason" align="center">
                </el-table-column>
                <el-table-column label="状态" prop="appealstatus" align="center">
                </el-table-column>
                <el-table-column label="操作" align="center">
                    <template slot-scope="scope">
                        <el-button type="text" @click="complain(scope.row,'申诉')" v-if="(scope.row.whetherCanAppeal === true) ? true :false">提出申诉</el-button>
                        <el-button type="text" @click="complain(scope.row,'审批')" v-if="(userType === 1 || userType === 2) && scope.row.appealstatus === '申诉中' ? true :false">审批</el-button>
                    </template>
                </el-table-column>
            </el-table>
            <br>
            <el-pagination
                v-show="recordTotal>0"
                :current-page="currentPage"
                :page-sizes="[10, 20, 30, 50]"
                :page-size="pageSize"
                :total="recordTotal"
                layout="total, sizes, prev, pager, next, jumper"
                background
                style="float:right;"
                @size-change="handleSizeChange"
                @current-change="handleCurrentChange"
            />
            <br>
        </div>
        <complain-form ref="form" @getinfo="getEnterpriseJudgeComplainDataList"></complain-form>
    </div>
</template>

<script>
import {getEnterpriseJudgeComplainData, enterpriseComplain} from "../../../api/enterpriseJudgeComplain";
import {computePageCount} from "../../../utils";
import {dictionaryAllItems} from "../../../api/dictionary";
import {parseError} from "../../../utils/messageDialog";
import ComplainForm from "./components/complainForm";
import {mapGetters} from "vuex";

export default {
    name: "registerReview",
    components: {ComplainForm},
    data(){
        return{
            pageSize: 10,
            recordTotal: 0,
            currentPage: 1,
            pageTotal: 0,
            tableKey: 0,
            listLoading:false,
            statusList:[],
            productJudgeData:[],
            punishmentMeasureList:[],
            appealStatusList:[{id:'UNAPPEALED',text:'未申诉'},{id:'APPEALING',text:'申诉中'},{id:'PASSED',text:'申诉通过'},{id:'UPPASSED',text:'申诉不通过'}],
            listQuery:{
                filter:{
                    enterprisename:'',
                    code:'',
                    appealstatus:'',
                },
                pageIndex:1,
                pageSize:10,
            },
        }
    },
    computed: {
        ...mapGetters([
            'userType',
            'username'
        ])
    },
    created() {
        this.getEnterpriseJudgeComplainDataList()
        this.getPunishmentTypeList()
    },
    methods:{
        async getEnterpriseJudgeComplainDataList(){
            this.listLoading = true
            let res = await getEnterpriseJudgeComplainData(this.listQuery)
            if(res.data.code === "200"){
                this.recordTotal = res.data.result.total
                this.pageSize = res.data.result.size
                this.pageTotal = computePageCount(res.data.result.totalCount, res.data.result.pageSize)
                this.currentPage = res.data.result.current
                this.productJudgeData = res.data.result.records
            }else{
                this.$message({
                    type:'warning',
                    message:res.data.message
                })
            }
            this.listLoading = false
        },
        complain(val,value){
            this.$refs.form.showComplainForm(val,value)
        },
        search(){
            this.getEnterpriseJudgeComplainDataList()
        },
        handleSizeChange: function(val) {
            this.listQuery.pageSize = val
            this.getEnterpriseJudgeComplainDataList()
        },
        handleCurrentChange: function(val) {
            this.listQuery.pageIndex = val
            this.getEnterpriseJudgeComplainDataList()
        },
        getPunishmentTypeList(){
            const _this = this
            if (_this.levelOptions && _this.levelOptions.length > 0) {
                return
            }
            const params = {}
            params['dictionaryType'] = '处罚类型'
            dictionaryAllItems(params).then(response => {
                const res = response.data
                if (res.code == 200) {
                    _this.punishmentMeasureList = res.result
                    console.log(_this.punishmentMeasureList);
                } else {
                    parseError({error: res.message, vm: _this})
                }
            }).catch(error => {
                parseError({error: error, vm: _this})
            })
        },//获取处罚类型
    },
}
</script>

<style scoped>
.basic_search{
    display:inline-block;
}
.warn-tip{
    color: red;
}
</style>
